==> dojo-1.11.4.tgz: package/cldr/nls/id/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "sekarang",
	"field-weekday": "Hari dalam Seminggu",
	"field-wed-relative+0": "Rabu ini",
	"field-wed-relative+1": "Rabu berikutnya",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-tue-relative+-1": "Selasa lalu",
	"dateFormat-long": "d MMMM y G",
	"field-fri-relative+-1": "Jumat lalu",
	"field-wed-relative+-1": "Rabu lalu",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateTimeFormat-medium": "{1} {0}",
	"dateFormat-full": "EEEE, dd MMMM y G",
	"dateFormatItem-yyyyMEd": "E, d/M/y G",
	"field-thu-relative+-1": "Kamis lalu",
	"dateFormatItem-Md": "d/M",
	"field-era": "Era",
	"field-year": "Tahun",
	"field-hour": "Jam",
	"field-sat-relative+0": "Sabtu ini",
	"field-sat-relative+1": "Sabtu berikutnya",
	"field-day-relative+0": "hari ini",
	"field-day-relative+1": "besok",
	"field-thu-relative+0": "Kamis ini",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "lusa",
	"field-thu-relative+1": "Kamis berikutnya",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-sun-relative+0": "Minggu ini",
	"dateFormatItem-Hm": "HH.mm",
	"field-sun-relative+1": "Minggu berikutnya",
	"field-minute": "Menit",
	"field-dayperiod": "AM/PM",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm.ss",
	"field-day-relative+-1": "kemarin",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "kemarin lusa",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d/M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "Jumat ini",
	"field-fri-relative+1": "Jumat berikutnya",
	"field-day": "Hari",
	"field-zone": "Zona Waktu",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "tahun lalu",
	"field-month-relative+-1": "bulan lalu",
	"dateFormatItem-hm": "h.mm a",
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-month": "Bulan",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "Selasa ini",
	"field-tue-relative+1": "Selasa berikutnya",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"field-mon-relative+0": "Senin ini",
	"field-mon-relative+1": "Senin berikutnya",
	"dateFormat-short": "dd/MM/yy GGGGG",
	"field-second": "Detik",
	"field-sat-relative+-1": "Sabtu lalu",
	"field-sun-relative+-1": "Minggu lalu",
	"field-month-relative+0": "bulan ini",
	"field-month-relative+1": "Bulan berikutnya",
	"dateFormatItem-Ed": "E, d",
	"field-week": "Minggu",
	"dateFormat-medium": "d MMM y G",
	"field-year-relative+0": "tahun ini",
	"field-week-relative+-1": "minggu lalu",
	"dateFormatItem-yyyyM": "M/y G",
	"field-year-relative+1": "tahun depan",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "Senin lalu",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "minggu ini",
	"field-week-relative+1": "Minggu berikutnya"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/id/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "sekarang",
	"field-weekday": "Hari dalam Seminggu",
	"field-wed-relative+0": "Rabu ini",
	"field-wed-relative+1": "Rabu berikutnya",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-tue-relative+-1": "Selasa lalu",
	"dateFormat-long": "d MMMM y G",
	"field-fri-relative+-1": "Jumat lalu",
	"field-wed-relative+-1": "Rabu lalu",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateTimeFormat-medium": "{1} {0}",
	"dateFormat-full": "EEEE, dd MMMM y G",
	"dateFormatItem-yyyyMEd": "E, d/M/y G",
	"field-thu-relative+-1": "Kamis lalu",
	"dateFormatItem-Md": "d/M",
	"field-era": "Era",
	"field-year": "Tahun",
	"field-hour": "Jam",
	"field-sat-relative+0": "Sabtu ini",
	"field-sat-relative+1": "Sabtu berikutnya",
	"field-day-relative+0": "hari ini",
	"field-day-relative+1": "besok",
	"field-thu-relative+0": "Kamis ini",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "lusa",
	"field-thu-relative+1": "Kamis berikutnya",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-sun-relative+0": "hari Minggu ini",
	"dateFormatItem-Hm": "HH.mm",
	"field-sun-relative+1": "hari Minggu berikutnya",
	"field-minute": "Menit",
	"field-dayperiod": "AM/PM",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm.ss",
	"field-day-relative+-1": "kemarin",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "kemarin lusa",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d/M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "Jumat ini",
	"field-fri-relative+1": "Jumat berikutnya",
	"field-day": "Hari",
	"field-zone": "Zona Waktu",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "tahun lalu",
	"field-month-relative+-1": "bulan lalu",
	"dateFormatItem-hm": "h.mm a",
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-month": "Bulan",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "Selasa ini",
	"field-tue-relative+1": "Selasa berikutnya",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"field-mon-relative+0": "Senin ini",
	"field-mon-relative+1": "Senin berikutnya",
	"dateFormat-short": "dd/MM/yy GGGGG",
	"field-second": "Detik",
	"field-sat-relative+-1": "Sabtu lalu",
	"field-sun-relative+-1": "hari Minggu lalu",
	"field-month-relative+0": "bulan ini",
	"field-month-relative+1": "Bulan berikutnya",
	"dateFormatItem-Ed": "E, d",
	"field-week": "Minggu",
	"dateFormat-medium": "d MMM y G",
	"field-year-relative+0": "tahun ini",
	"field-week-relative+-1": "minggu lalu",
	"dateFormatItem-yyyyM": "M/y G",
	"field-year-relative+1": "tahun depan",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "Senin lalu",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "minggu ini",
	"field-week-relative+1": "minggu berikutnya"
}
//end v1.x content
);
